# Tsetlin Machine Unified - One Codebase to Rule Them All
![License](https://img.shields.io/github/license/microsoft/interpret.svg?style=flat-square) ![Python Version](https://img.shields.io/pypi/pyversions/interpret.svg?style=flat-square)![Maintenance](https://img.shields.io/maintenance/yes/2023?style=flat-square)

Implements the Tsetlin Machine (https://arxiv.org/abs/1804.01508), Coalesced Tsetlin Machine (https://arxiv.org/abs/2108.07594), Convolutional Tsetlin Machine (https://arxiv.org/abs/1905.09688), Regression Tsetlin Machine (https://royalsocietypublishing.org/doi/full/10.1098/rsta.2019.0165), and Weighted Tsetlin Machine (https://ieeexplore.ieee.org/document/9316190), with support for continuous features (https://arxiv.org/abs/1905.04199), drop clause (https://arxiv.org/abs/2105.14506), Type III Feedback (to be published), focused negative sampling (https://ieeexplore.ieee.org/document/9923859), multi-task classifier (to be published), autoencoder (https://arxiv.org/abs/2301.00709), literal budget (to be published), incremental clause evaluation (to be published), and one-vs-one multi-class classifier (to be published). TMU is written in Python with wrappers for C and CUDA-based clause evaluation and updating.
